@@ -36,7 +36,7 @@ except ImportError:
 from ploomber_core.telemetry.telemetry import Telemetry
 
 telemetry = Telemetry(
-    api_key="phc_TaEJeL7zLyyYWDi9rqtFakoPbtfHkLNiWAG3iuXVzH0",
+    api_key="phc_P9SpSeypyPwxrMdFn2edOOEooQioF2axppyEeDwtMSP",
     package_name="jupysql",
     version=version("jupysql"),
 )
